User Guide — MoviePy 1.0.1 documentation

MoviePy is a Python module for video editing, which can be used for basic operations (like cuts, concatenations, title insertions), video compositing (a.k.a. non-linear editing), video processing, or to create advanced effects. It can read and write the most common video formats, including GIF.

Here it is in action (run in an IPython Notebook):

# User Guide

- Download and Installation
- Getting started with MoviePy
- Gallery
- Example Scripts
- Moviepy Docker
- So you want to install OpenCV 2.4.6 ?
- FAQ and troubleshooting
- Advanced tools
- Reference Manual

# Contribute !

MoviePy is an open source software originally written by Zulko and released under the MIT licence. It works on Windows, Mac, and Linux, with Python 2 or Python 3. The code is hosted on Github, where you can push improvements, report bugs and ask for help. There is also a MoviePy forum on Reddit and a mailing list on librelist .

Tweet